#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-76KAipj3OEi3sVK1qrezdT
key:                  http-streams-0.8.9.9-76KAipj3OEi3sVK1qrezdT
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  d643270b92983bae9a43a9abea106c43
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-76KAipj3OEi3sVK1qrezdT
depends:
    HsOpenSSL-0.11.7.10-KkWOBA8bpmBK42QZeYTnB5
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    attoparsec-0.14.4-qc2ScMijHsIVylJ0k0iua
    attoparsec-aeson-2.2.2.0-57Ahc1UJZboK3lInrrCGeb base-4.18.2.1
    base64-bytestring-1.2.1.0-LOSDeSQSndy1Y93aTSzs7h
    blaze-builder-0.4.4.1-3ZGNeeLUhPeI237uQ0tBgU bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9SCmNmyRT1LDc1Bi3mXj6e directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-ANy3XAzsGRXCYBFITYw8s7
    io-streams-1.5.2.2-s1Q2A726lWD41DQgkbVzp mtl-2.3.1
    network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o
    network-uri-2.6.4.2-1CJs0qlSGKv7cmTNxU9YR0
    openssl-streams-1.2.3.0-28EtJcLziPjHNnIU6R1iJZ text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

